# -*- coding: utf-8 -*-
#
# This file is part of the parce Python package.
#
# Copyright © 2019-2020 by Wilbert Berendsen <info@wilbertberendsen.nl>
#
# This module is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This module is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

"""
Validates all languages with pytest.
"""

import sys

sys.path.insert(0, ".")

from parce.registry import registry, root_lexicon
from parce.validate import validate_language

def test_main():
    for lexicon_name in registry:
        lang = root_lexicon(lexicon_name).language
        assert validate_language(lang) is True


if __name__ == "__main__":
    test_main()
